import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class DataprocMetastoreResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class ProjectsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class LocationsResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class FederationsResource(googleapiclient.discovery.Resource):
                def create(
                    self,
                    *,
                    parent: str,
                    body: Federation = ...,
                    federationId: str = ...,
                    requestId: str = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def delete(
                    self, *, name: str, requestId: str = ..., **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> FederationHttpRequest: ...
                def getIamPolicy(
                    self,
                    *,
                    resource: str,
                    options_requestedPolicyVersion: int = ...,
                    **kwargs: typing.Any
                ) -> PolicyHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    filter: str = ...,
                    orderBy: str = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListFederationsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListFederationsResponseHttpRequest,
                    previous_response: ListFederationsResponse,
                ) -> ListFederationsResponseHttpRequest | None: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: Federation = ...,
                    requestId: str = ...,
                    updateMask: str = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def setIamPolicy(
                    self,
                    *,
                    resource: str,
                    body: SetIamPolicyRequest = ...,
                    **kwargs: typing.Any
                ) -> PolicyHttpRequest: ...
                def testIamPermissions(
                    self,
                    *,
                    resource: str,
                    body: TestIamPermissionsRequest = ...,
                    **kwargs: typing.Any
                ) -> TestIamPermissionsResponseHttpRequest: ...

            @typing.type_check_only
            class OperationsResource(googleapiclient.discovery.Resource):
                def delete(
                    self, *, name: str, **kwargs: typing.Any
                ) -> EmptyHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def list(
                    self,
                    *,
                    name: str,
                    filter: str = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListOperationsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListOperationsResponseHttpRequest,
                    previous_response: ListOperationsResponse,
                ) -> ListOperationsResponseHttpRequest | None: ...

            @typing.type_check_only
            class ServicesResource(googleapiclient.discovery.Resource):
                @typing.type_check_only
                class BackupsResource(googleapiclient.discovery.Resource):
                    def create(
                        self,
                        *,
                        parent: str,
                        body: Backup = ...,
                        backupId: str = ...,
                        requestId: str = ...,
                        **kwargs: typing.Any
                    ) -> OperationHttpRequest: ...
                    def delete(
                        self, *, name: str, requestId: str = ..., **kwargs: typing.Any
                    ) -> OperationHttpRequest: ...
                    def get(
                        self, *, name: str, **kwargs: typing.Any
                    ) -> BackupHttpRequest: ...
                    def getIamPolicy(
                        self,
                        *,
                        resource: str,
                        options_requestedPolicyVersion: int = ...,
                        **kwargs: typing.Any
                    ) -> PolicyHttpRequest: ...
                    def list(
                        self,
                        *,
                        parent: str,
                        filter: str = ...,
                        orderBy: str = ...,
                        pageSize: int = ...,
                        pageToken: str = ...,
                        **kwargs: typing.Any
                    ) -> ListBackupsResponseHttpRequest: ...
                    def list_next(
                        self,
                        previous_request: ListBackupsResponseHttpRequest,
                        previous_response: ListBackupsResponse,
                    ) -> ListBackupsResponseHttpRequest | None: ...
                    def setIamPolicy(
                        self,
                        *,
                        resource: str,
                        body: SetIamPolicyRequest = ...,
                        **kwargs: typing.Any
                    ) -> PolicyHttpRequest: ...
                    def testIamPermissions(
                        self,
                        *,
                        resource: str,
                        body: TestIamPermissionsRequest = ...,
                        **kwargs: typing.Any
                    ) -> TestIamPermissionsResponseHttpRequest: ...

                @typing.type_check_only
                class DatabasesResource(googleapiclient.discovery.Resource):
                    @typing.type_check_only
                    class TablesResource(googleapiclient.discovery.Resource):
                        def getIamPolicy(
                            self,
                            *,
                            resource: str,
                            options_requestedPolicyVersion: int = ...,
                            **kwargs: typing.Any
                        ) -> PolicyHttpRequest: ...
                        def setIamPolicy(
                            self,
                            *,
                            resource: str,
                            body: SetIamPolicyRequest = ...,
                            **kwargs: typing.Any
                        ) -> PolicyHttpRequest: ...
                        def testIamPermissions(
                            self,
                            *,
                            resource: str,
                            body: TestIamPermissionsRequest = ...,
                            **kwargs: typing.Any
                        ) -> TestIamPermissionsResponseHttpRequest: ...

                    def getIamPolicy(
                        self,
                        *,
                        resource: str,
                        options_requestedPolicyVersion: int = ...,
                        **kwargs: typing.Any
                    ) -> PolicyHttpRequest: ...
                    def setIamPolicy(
                        self,
                        *,
                        resource: str,
                        body: SetIamPolicyRequest = ...,
                        **kwargs: typing.Any
                    ) -> PolicyHttpRequest: ...
                    def testIamPermissions(
                        self,
                        *,
                        resource: str,
                        body: TestIamPermissionsRequest = ...,
                        **kwargs: typing.Any
                    ) -> TestIamPermissionsResponseHttpRequest: ...
                    def tables(self) -> TablesResource: ...

                @typing.type_check_only
                class MetadataImportsResource(googleapiclient.discovery.Resource):
                    def create(
                        self,
                        *,
                        parent: str,
                        body: MetadataImport = ...,
                        metadataImportId: str = ...,
                        requestId: str = ...,
                        **kwargs: typing.Any
                    ) -> OperationHttpRequest: ...
                    def get(
                        self, *, name: str, **kwargs: typing.Any
                    ) -> MetadataImportHttpRequest: ...
                    def list(
                        self,
                        *,
                        parent: str,
                        filter: str = ...,
                        orderBy: str = ...,
                        pageSize: int = ...,
                        pageToken: str = ...,
                        **kwargs: typing.Any
                    ) -> ListMetadataImportsResponseHttpRequest: ...
                    def list_next(
                        self,
                        previous_request: ListMetadataImportsResponseHttpRequest,
                        previous_response: ListMetadataImportsResponse,
                    ) -> ListMetadataImportsResponseHttpRequest | None: ...
                    def patch(
                        self,
                        *,
                        name: str,
                        body: MetadataImport = ...,
                        requestId: str = ...,
                        updateMask: str = ...,
                        **kwargs: typing.Any
                    ) -> OperationHttpRequest: ...

                def create(
                    self,
                    *,
                    parent: str,
                    body: Service = ...,
                    requestId: str = ...,
                    serviceId: str = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def delete(
                    self, *, name: str, requestId: str = ..., **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def exportMetadata(
                    self,
                    *,
                    service: str,
                    body: ExportMetadataRequest = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> ServiceHttpRequest: ...
                def getIamPolicy(
                    self,
                    *,
                    resource: str,
                    options_requestedPolicyVersion: int = ...,
                    **kwargs: typing.Any
                ) -> PolicyHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    filter: str = ...,
                    orderBy: str = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListServicesResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListServicesResponseHttpRequest,
                    previous_response: ListServicesResponse,
                ) -> ListServicesResponseHttpRequest | None: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: Service = ...,
                    requestId: str = ...,
                    updateMask: str = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def removeIamPolicy(
                    self,
                    *,
                    resource: str,
                    body: RemoveIamPolicyRequest = ...,
                    **kwargs: typing.Any
                ) -> RemoveIamPolicyResponseHttpRequest: ...
                def restore(
                    self,
                    *,
                    service: str,
                    body: RestoreServiceRequest = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def setIamPolicy(
                    self,
                    *,
                    resource: str,
                    body: SetIamPolicyRequest = ...,
                    **kwargs: typing.Any
                ) -> PolicyHttpRequest: ...
                def testIamPermissions(
                    self,
                    *,
                    resource: str,
                    body: TestIamPermissionsRequest = ...,
                    **kwargs: typing.Any
                ) -> TestIamPermissionsResponseHttpRequest: ...
                def backups(self) -> BackupsResource: ...
                def databases(self) -> DatabasesResource: ...
                def metadataImports(self) -> MetadataImportsResource: ...

            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> LocationHttpRequest: ...
            def list(
                self,
                *,
                name: str,
                filter: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListLocationsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListLocationsResponseHttpRequest,
                previous_response: ListLocationsResponse,
            ) -> ListLocationsResponseHttpRequest | None: ...
            def federations(self) -> FederationsResource: ...
            def operations(self) -> OperationsResource: ...
            def services(self) -> ServicesResource: ...

        def locations(self) -> LocationsResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def projects(self) -> ProjectsResource: ...

@typing.type_check_only
class BackupHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Backup: ...

@typing.type_check_only
class EmptyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Empty: ...

@typing.type_check_only
class FederationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Federation: ...

@typing.type_check_only
class ListBackupsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListBackupsResponse: ...

@typing.type_check_only
class ListFederationsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListFederationsResponse: ...

@typing.type_check_only
class ListLocationsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListLocationsResponse: ...

@typing.type_check_only
class ListMetadataImportsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListMetadataImportsResponse: ...

@typing.type_check_only
class ListOperationsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListOperationsResponse: ...

@typing.type_check_only
class ListServicesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListServicesResponse: ...

@typing.type_check_only
class LocationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Location: ...

@typing.type_check_only
class MetadataImportHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> MetadataImport: ...

@typing.type_check_only
class OperationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Operation: ...

@typing.type_check_only
class PolicyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Policy: ...

@typing.type_check_only
class RemoveIamPolicyResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> RemoveIamPolicyResponse: ...

@typing.type_check_only
class ServiceHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Service: ...

@typing.type_check_only
class TestIamPermissionsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> TestIamPermissionsResponse: ...



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class ResourceSettingsResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class FoldersResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class SettingsResource(googleapiclient.discovery.Resource):
            def get(
                self,
                *,
                name: str,
                view: typing_extensions.Literal[
                    "SETTING_VIEW_UNSPECIFIED",
                    "SETTING_VIEW_BASIC",
                    "SETTING_VIEW_EFFECTIVE_VALUE",
                    "SETTING_VIEW_LOCAL_VALUE",
                ] = ...,
                **kwargs: typing.Any
            ) -> GoogleCloudResourcesettingsV1SettingHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                pageSize: int = ...,
                pageToken: str = ...,
                view: typing_extensions.Literal[
                    "SETTING_VIEW_UNSPECIFIED",
                    "SETTING_VIEW_BASIC",
                    "SETTING_VIEW_EFFECTIVE_VALUE",
                    "SETTING_VIEW_LOCAL_VALUE",
                ] = ...,
                **kwargs: typing.Any
            ) -> GoogleCloudResourcesettingsV1ListSettingsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: GoogleCloudResourcesettingsV1ListSettingsResponseHttpRequest,
                previous_response: GoogleCloudResourcesettingsV1ListSettingsResponse,
            ) -> GoogleCloudResourcesettingsV1ListSettingsResponseHttpRequest | None: ...
            def patch(
                self,
                *,
                name: str,
                body: GoogleCloudResourcesettingsV1Setting = ...,
                **kwargs: typing.Any
            ) -> GoogleCloudResourcesettingsV1SettingHttpRequest: ...

        def settings(self) -> SettingsResource: ...

    @typing.type_check_only
    class OrganizationsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class SettingsResource(googleapiclient.discovery.Resource):
            def get(
                self,
                *,
                name: str,
                view: typing_extensions.Literal[
                    "SETTING_VIEW_UNSPECIFIED",
                    "SETTING_VIEW_BASIC",
                    "SETTING_VIEW_EFFECTIVE_VALUE",
                    "SETTING_VIEW_LOCAL_VALUE",
                ] = ...,
                **kwargs: typing.Any
            ) -> GoogleCloudResourcesettingsV1SettingHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                pageSize: int = ...,
                pageToken: str = ...,
                view: typing_extensions.Literal[
                    "SETTING_VIEW_UNSPECIFIED",
                    "SETTING_VIEW_BASIC",
                    "SETTING_VIEW_EFFECTIVE_VALUE",
                    "SETTING_VIEW_LOCAL_VALUE",
                ] = ...,
                **kwargs: typing.Any
            ) -> GoogleCloudResourcesettingsV1ListSettingsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: GoogleCloudResourcesettingsV1ListSettingsResponseHttpRequest,
                previous_response: GoogleCloudResourcesettingsV1ListSettingsResponse,
            ) -> GoogleCloudResourcesettingsV1ListSettingsResponseHttpRequest | None: ...
            def patch(
                self,
                *,
                name: str,
                body: GoogleCloudResourcesettingsV1Setting = ...,
                **kwargs: typing.Any
            ) -> GoogleCloudResourcesettingsV1SettingHttpRequest: ...

        def settings(self) -> SettingsResource: ...

    @typing.type_check_only
    class ProjectsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class SettingsResource(googleapiclient.discovery.Resource):
            def get(
                self,
                *,
                name: str,
                view: typing_extensions.Literal[
                    "SETTING_VIEW_UNSPECIFIED",
                    "SETTING_VIEW_BASIC",
                    "SETTING_VIEW_EFFECTIVE_VALUE",
                    "SETTING_VIEW_LOCAL_VALUE",
                ] = ...,
                **kwargs: typing.Any
            ) -> GoogleCloudResourcesettingsV1SettingHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                pageSize: int = ...,
                pageToken: str = ...,
                view: typing_extensions.Literal[
                    "SETTING_VIEW_UNSPECIFIED",
                    "SETTING_VIEW_BASIC",
                    "SETTING_VIEW_EFFECTIVE_VALUE",
                    "SETTING_VIEW_LOCAL_VALUE",
                ] = ...,
                **kwargs: typing.Any
            ) -> GoogleCloudResourcesettingsV1ListSettingsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: GoogleCloudResourcesettingsV1ListSettingsResponseHttpRequest,
                previous_response: GoogleCloudResourcesettingsV1ListSettingsResponse,
            ) -> GoogleCloudResourcesettingsV1ListSettingsResponseHttpRequest | None: ...
            def patch(
                self,
                *,
                name: str,
                body: GoogleCloudResourcesettingsV1Setting = ...,
                **kwargs: typing.Any
            ) -> GoogleCloudResourcesettingsV1SettingHttpRequest: ...

        def settings(self) -> SettingsResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def folders(self) -> FoldersResource: ...
    def organizations(self) -> OrganizationsResource: ...
    def projects(self) -> ProjectsResource: ...

@typing.type_check_only
class GoogleCloudResourcesettingsV1ListSettingsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudResourcesettingsV1ListSettingsResponse: ...

@typing.type_check_only
class GoogleCloudResourcesettingsV1SettingHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudResourcesettingsV1Setting: ...



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class SecurityCommandCenterResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class FoldersResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class ContainerThreatDetectionSettingsResource(
            googleapiclient.discovery.Resource
        ):
            def calculate(
                self, *, name: str, **kwargs: typing.Any
            ) -> ContainerThreatDetectionSettingsHttpRequest: ...

        @typing.type_check_only
        class EventThreatDetectionSettingsResource(googleapiclient.discovery.Resource):
            def calculate(
                self, *, name: str, **kwargs: typing.Any
            ) -> EventThreatDetectionSettingsHttpRequest: ...

        @typing.type_check_only
        class RapidVulnerabilityDetectionSettingsResource(
            googleapiclient.discovery.Resource
        ):
            def calculate(
                self, *, name: str, **kwargs: typing.Any
            ) -> RapidVulnerabilityDetectionSettingsHttpRequest: ...

        @typing.type_check_only
        class SecurityHealthAnalyticsSettingsResource(
            googleapiclient.discovery.Resource
        ):
            def calculate(
                self, *, name: str, **kwargs: typing.Any
            ) -> SecurityHealthAnalyticsSettingsHttpRequest: ...

        @typing.type_check_only
        class VirtualMachineThreatDetectionSettingsResource(
            googleapiclient.discovery.Resource
        ):
            def calculate(
                self, *, name: str, **kwargs: typing.Any
            ) -> VirtualMachineThreatDetectionSettingsHttpRequest: ...

        @typing.type_check_only
        class WebSecurityScannerSettingsResource(googleapiclient.discovery.Resource):
            def calculate(
                self, *, name: str, **kwargs: typing.Any
            ) -> WebSecurityScannerSettingsHttpRequest: ...

        def getContainerThreatDetectionSettings(
            self, *, name: str, **kwargs: typing.Any
        ) -> ContainerThreatDetectionSettingsHttpRequest: ...
        def getEventThreatDetectionSettings(
            self, *, name: str, **kwargs: typing.Any
        ) -> EventThreatDetectionSettingsHttpRequest: ...
        def getOnboardingState(
            self, *, name: str, **kwargs: typing.Any
        ) -> OnboardingStateHttpRequest: ...
        def getRapidVulnerabilityDetectionSettings(
            self, *, name: str, **kwargs: typing.Any
        ) -> RapidVulnerabilityDetectionSettingsHttpRequest: ...
        def getSecurityCenterSettings(
            self, *, name: str, **kwargs: typing.Any
        ) -> SecurityCenterSettingsHttpRequest: ...
        def getSecurityHealthAnalyticsSettings(
            self, *, name: str, **kwargs: typing.Any
        ) -> SecurityHealthAnalyticsSettingsHttpRequest: ...
        def getVirtualMachineThreatDetectionSettings(
            self, *, name: str, **kwargs: typing.Any
        ) -> VirtualMachineThreatDetectionSettingsHttpRequest: ...
        def getWebSecurityScannerSettings(
            self, *, name: str, **kwargs: typing.Any
        ) -> WebSecurityScannerSettingsHttpRequest: ...
        def updateContainerThreatDetectionSettings(
            self,
            *,
            name: str,
            body: ContainerThreatDetectionSettings = ...,
            updateMask: str = ...,
            **kwargs: typing.Any
        ) -> ContainerThreatDetectionSettingsHttpRequest: ...
        def updateEventThreatDetectionSettings(
            self,
            *,
            name: str,
            body: EventThreatDetectionSettings = ...,
            updateMask: str = ...,
            **kwargs: typing.Any
        ) -> EventThreatDetectionSettingsHttpRequest: ...
        def updateRapidVulnerabilityDetectionSettings(
            self,
            *,
            name: str,
            body: RapidVulnerabilityDetectionSettings = ...,
            updateMask: str = ...,
            **kwargs: typing.Any
        ) -> RapidVulnerabilityDetectionSettingsHttpRequest: ...
        def updateSecurityHealthAnalyticsSettings(
            self,
            *,
            name: str,
            body: SecurityHealthAnalyticsSettings = ...,
            updateMask: str = ...,
            **kwargs: typing.Any
        ) -> SecurityHealthAnalyticsSettingsHttpRequest: ...
        def updateVirtualMachineThreatDetectionSettings(
            self,
            *,
            name: str,
            body: VirtualMachineThreatDetectionSettings = ...,
            updateMask: str = ...,
            **kwargs: typing.Any
        ) -> VirtualMachineThreatDetectionSettingsHttpRequest: ...
        def updateWebSecurityScannerSettings(
            self,
            *,
            name: str,
            body: WebSecurityScannerSettings = ...,
            updateMask: str = ...,
            **kwargs: typing.Any
        ) -> WebSecurityScannerSettingsHttpRequest: ...
        def containerThreatDetectionSettings(
            self,
        ) -> ContainerThreatDetectionSettingsResource: ...
        def eventThreatDetectionSettings(
            self,
        ) -> EventThreatDetectionSettingsResource: ...
        def rapidVulnerabilityDetectionSettings(
            self,
        ) -> RapidVulnerabilityDetectionSettingsResource: ...
        def securityHealthAnalyticsSettings(
            self,
        ) -> SecurityHealthAnalyticsSettingsResource: ...
        def virtualMachineThreatDetectionSettings(
            self,
        ) -> VirtualMachineThreatDetectionSettingsResource: ...
        def webSecurityScannerSettings(self) -> WebSecurityScannerSettingsResource: ...

    @typing.type_check_only
    class OrganizationsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class ContainerThreatDetectionSettingsResource(
            googleapiclient.discovery.Resource
        ):
            def calculate(
                self, *, name: str, **kwargs: typing.Any
            ) -> ContainerThreatDetectionSettingsHttpRequest: ...

        @typing.type_check_only
        class EventThreatDetectionSettingsResource(googleapiclient.discovery.Resource):
            def calculate(
                self, *, name: str, **kwargs: typing.Any
            ) -> EventThreatDetectionSettingsHttpRequest: ...

        @typing.type_check_only
        class RapidVulnerabilityDetectionSettingsResource(
            googleapiclient.discovery.Resource
        ):
            def calculate(
                self, *, name: str, **kwargs: typing.Any
            ) -> RapidVulnerabilityDetectionSettingsHttpRequest: ...

        @typing.type_check_only
        class SecurityHealthAnalyticsSettingsResource(
            googleapiclient.discovery.Resource
        ):
            def calculate(
                self, *, name: str, **kwargs: typing.Any
            ) -> SecurityHealthAnalyticsSettingsHttpRequest: ...

        @typing.type_check_only
        class VirtualMachineThreatDetectionSettingsResource(
            googleapiclient.discovery.Resource
        ):
            def calculate(
                self, *, name: str, **kwargs: typing.Any
            ) -> VirtualMachineThreatDetectionSettingsHttpRequest: ...

        @typing.type_check_only
        class WebSecurityScannerSettingsResource(googleapiclient.discovery.Resource):
            def calculate(
                self, *, name: str, **kwargs: typing.Any
            ) -> WebSecurityScannerSettingsHttpRequest: ...

        def getContainerThreatDetectionSettings(
            self, *, name: str, **kwargs: typing.Any
        ) -> ContainerThreatDetectionSettingsHttpRequest: ...
        def getEventThreatDetectionSettings(
            self, *, name: str, **kwargs: typing.Any
        ) -> EventThreatDetectionSettingsHttpRequest: ...
        def getOnboardingState(
            self, *, name: str, **kwargs: typing.Any
        ) -> OnboardingStateHttpRequest: ...
        def getRapidVulnerabilityDetectionSettings(
            self, *, name: str, **kwargs: typing.Any
        ) -> RapidVulnerabilityDetectionSettingsHttpRequest: ...
        def getSecurityCenterSettings(
            self, *, name: str, **kwargs: typing.Any
        ) -> SecurityCenterSettingsHttpRequest: ...
        def getSecurityHealthAnalyticsSettings(
            self, *, name: str, **kwargs: typing.Any
        ) -> SecurityHealthAnalyticsSettingsHttpRequest: ...
        def getSubscription(
            self, *, name: str, **kwargs: typing.Any
        ) -> SubscriptionHttpRequest: ...
        def getVirtualMachineThreatDetectionSettings(
            self, *, name: str, **kwargs: typing.Any
        ) -> VirtualMachineThreatDetectionSettingsHttpRequest: ...
        def getWebSecurityScannerSettings(
            self, *, name: str, **kwargs: typing.Any
        ) -> WebSecurityScannerSettingsHttpRequest: ...
        def updateContainerThreatDetectionSettings(
            self,
            *,
            name: str,
            body: ContainerThreatDetectionSettings = ...,
            updateMask: str = ...,
            **kwargs: typing.Any
        ) -> ContainerThreatDetectionSettingsHttpRequest: ...
        def updateEventThreatDetectionSettings(
            self,
            *,
            name: str,
            body: EventThreatDetectionSettings = ...,
            updateMask: str = ...,
            **kwargs: typing.Any
        ) -> EventThreatDetectionSettingsHttpRequest: ...
        def updateRapidVulnerabilityDetectionSettings(
            self,
            *,
            name: str,
            body: RapidVulnerabilityDetectionSettings = ...,
            updateMask: str = ...,
            **kwargs: typing.Any
        ) -> RapidVulnerabilityDetectionSettingsHttpRequest: ...
        def updateSecurityHealthAnalyticsSettings(
            self,
            *,
            name: str,
            body: SecurityHealthAnalyticsSettings = ...,
            updateMask: str = ...,
            **kwargs: typing.Any
        ) -> SecurityHealthAnalyticsSettingsHttpRequest: ...
        def updateVirtualMachineThreatDetectionSettings(
            self,
            *,
            name: str,
            body: VirtualMachineThreatDetectionSettings = ...,
            updateMask: str = ...,
            **kwargs: typing.Any
        ) -> VirtualMachineThreatDetectionSettingsHttpRequest: ...
        def updateWebSecurityScannerSettings(
            self,
            *,
            name: str,
            body: WebSecurityScannerSettings = ...,
            updateMask: str = ...,
            **kwargs: typing.Any
        ) -> WebSecurityScannerSettingsHttpRequest: ...
        def containerThreatDetectionSettings(
            self,
        ) -> ContainerThreatDetectionSettingsResource: ...
        def eventThreatDetectionSettings(
            self,
        ) -> EventThreatDetectionSettingsResource: ...
        def rapidVulnerabilityDetectionSettings(
            self,
        ) -> RapidVulnerabilityDetectionSettingsResource: ...
        def securityHealthAnalyticsSettings(
            self,
        ) -> SecurityHealthAnalyticsSettingsResource: ...
        def virtualMachineThreatDetectionSettings(
            self,
        ) -> VirtualMachineThreatDetectionSettingsResource: ...
        def webSecurityScannerSettings(self) -> WebSecurityScannerSettingsResource: ...

    @typing.type_check_only
    class ProjectsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class ContainerThreatDetectionSettingsResource(
            googleapiclient.discovery.Resource
        ):
            def calculate(
                self, *, name: str, **kwargs: typing.Any
            ) -> ContainerThreatDetectionSettingsHttpRequest: ...

        @typing.type_check_only
        class EventThreatDetectionSettingsResource(googleapiclient.discovery.Resource):
            def calculate(
                self, *, name: str, **kwargs: typing.Any
            ) -> EventThreatDetectionSettingsHttpRequest: ...

        @typing.type_check_only
        class LocationsResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class ClustersResource(googleapiclient.discovery.Resource):
                @typing.type_check_only
                class ContainerThreatDetectionSettingsResource(
                    googleapiclient.discovery.Resource
                ):
                    def calculate(
                        self, *, name: str, **kwargs: typing.Any
                    ) -> ContainerThreatDetectionSettingsHttpRequest: ...

                def getContainerThreatDetectionSettings(
                    self, *, name: str, **kwargs: typing.Any
                ) -> ContainerThreatDetectionSettingsHttpRequest: ...
                def updateContainerThreatDetectionSettings(
                    self,
                    *,
                    name: str,
                    body: ContainerThreatDetectionSettings = ...,
                    updateMask: str = ...,
                    **kwargs: typing.Any
                ) -> ContainerThreatDetectionSettingsHttpRequest: ...
                def containerThreatDetectionSettings(
                    self,
                ) -> ContainerThreatDetectionSettingsResource: ...

            def clusters(self) -> ClustersResource: ...

        @typing.type_check_only
        class RapidVulnerabilityDetectionSettingsResource(
            googleapiclient.discovery.Resource
        ):
            def calculate(
                self, *, name: str, **kwargs: typing.Any
            ) -> RapidVulnerabilityDetectionSettingsHttpRequest: ...

        @typing.type_check_only
        class SecurityHealthAnalyticsSettingsResource(
            googleapiclient.discovery.Resource
        ):
            def calculate(
                self, *, name: str, **kwargs: typing.Any
            ) -> SecurityHealthAnalyticsSettingsHttpRequest: ...

        @typing.type_check_only
        class VirtualMachineThreatDetectionSettingsResource(
            googleapiclient.discovery.Resource
        ):
            def calculate(
                self, *, name: str, **kwargs: typing.Any
            ) -> VirtualMachineThreatDetectionSettingsHttpRequest: ...

        @typing.type_check_only
        class WebSecurityScannerSettingsResource(googleapiclient.discovery.Resource):
            def calculate(
                self, *, name: str, **kwargs: typing.Any
            ) -> WebSecurityScannerSettingsHttpRequest: ...

        def getContainerThreatDetectionSettings(
            self, *, name: str, **kwargs: typing.Any
        ) -> ContainerThreatDetectionSettingsHttpRequest: ...
        def getEventThreatDetectionSettings(
            self, *, name: str, **kwargs: typing.Any
        ) -> EventThreatDetectionSettingsHttpRequest: ...
        def getOnboardingState(
            self, *, name: str, **kwargs: typing.Any
        ) -> OnboardingStateHttpRequest: ...
        def getRapidVulnerabilityDetectionSettings(
            self, *, name: str, **kwargs: typing.Any
        ) -> RapidVulnerabilityDetectionSettingsHttpRequest: ...
        def getSecurityCenterSettings(
            self, *, name: str, **kwargs: typing.Any
        ) -> SecurityCenterSettingsHttpRequest: ...
        def getSecurityHealthAnalyticsSettings(
            self, *, name: str, **kwargs: typing.Any
        ) -> SecurityHealthAnalyticsSettingsHttpRequest: ...
        def getVirtualMachineThreatDetectionSettings(
            self, *, name: str, **kwargs: typing.Any
        ) -> VirtualMachineThreatDetectionSettingsHttpRequest: ...
        def getWebSecurityScannerSettings(
            self, *, name: str, **kwargs: typing.Any
        ) -> WebSecurityScannerSettingsHttpRequest: ...
        def updateContainerThreatDetectionSettings(
            self,
            *,
            name: str,
            body: ContainerThreatDetectionSettings = ...,
            updateMask: str = ...,
            **kwargs: typing.Any
        ) -> ContainerThreatDetectionSettingsHttpRequest: ...
        def updateEventThreatDetectionSettings(
            self,
            *,
            name: str,
            body: EventThreatDetectionSettings = ...,
            updateMask: str = ...,
            **kwargs: typing.Any
        ) -> EventThreatDetectionSettingsHttpRequest: ...
        def updateRapidVulnerabilityDetectionSettings(
            self,
            *,
            name: str,
            body: RapidVulnerabilityDetectionSettings = ...,
            updateMask: str = ...,
            **kwargs: typing.Any
        ) -> RapidVulnerabilityDetectionSettingsHttpRequest: ...
        def updateSecurityHealthAnalyticsSettings(
            self,
            *,
            name: str,
            body: SecurityHealthAnalyticsSettings = ...,
            updateMask: str = ...,
            **kwargs: typing.Any
        ) -> SecurityHealthAnalyticsSettingsHttpRequest: ...
        def updateVirtualMachineThreatDetectionSettings(
            self,
            *,
            name: str,
            body: VirtualMachineThreatDetectionSettings = ...,
            updateMask: str = ...,
            **kwargs: typing.Any
        ) -> VirtualMachineThreatDetectionSettingsHttpRequest: ...
        def updateWebSecurityScannerSettings(
            self,
            *,
            name: str,
            body: WebSecurityScannerSettings = ...,
            updateMask: str = ...,
            **kwargs: typing.Any
        ) -> WebSecurityScannerSettingsHttpRequest: ...
        def containerThreatDetectionSettings(
            self,
        ) -> ContainerThreatDetectionSettingsResource: ...
        def eventThreatDetectionSettings(
            self,
        ) -> EventThreatDetectionSettingsResource: ...
        def locations(self) -> LocationsResource: ...
        def rapidVulnerabilityDetectionSettings(
            self,
        ) -> RapidVulnerabilityDetectionSettingsResource: ...
        def securityHealthAnalyticsSettings(
            self,
        ) -> SecurityHealthAnalyticsSettingsResource: ...
        def virtualMachineThreatDetectionSettings(
            self,
        ) -> VirtualMachineThreatDetectionSettingsResource: ...
        def webSecurityScannerSettings(self) -> WebSecurityScannerSettingsResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def folders(self) -> FoldersResource: ...
    def organizations(self) -> OrganizationsResource: ...
    def projects(self) -> ProjectsResource: ...

@typing.type_check_only
class ContainerThreatDetectionSettingsHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ContainerThreatDetectionSettings: ...

@typing.type_check_only
class EventThreatDetectionSettingsHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> EventThreatDetectionSettings: ...

@typing.type_check_only
class OnboardingStateHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> OnboardingState: ...

@typing.type_check_only
class RapidVulnerabilityDetectionSettingsHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> RapidVulnerabilityDetectionSettings: ...

@typing.type_check_only
class SecurityCenterSettingsHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> SecurityCenterSettings: ...

@typing.type_check_only
class SecurityHealthAnalyticsSettingsHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> SecurityHealthAnalyticsSettings: ...

@typing.type_check_only
class SubscriptionHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Subscription: ...

@typing.type_check_only
class VirtualMachineThreatDetectionSettingsHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> VirtualMachineThreatDetectionSettings: ...

@typing.type_check_only
class WebSecurityScannerSettingsHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> WebSecurityScannerSettings: ...



import typing

import typing_extensions

_list = list

@typing.type_check_only
class AdBreak(typing_extensions.TypedDict, total=False):
    startTimeOffset: str

@typing.type_check_only
class Aes128Encryption(typing_extensions.TypedDict, total=False):
    keyUri: str

@typing.type_check_only
class Animation(typing_extensions.TypedDict, total=False):
    animationEnd: AnimationEnd
    animationFade: AnimationFade
    animationStatic: AnimationStatic

@typing.type_check_only
class AnimationEnd(typing_extensions.TypedDict, total=False):
    startTimeOffset: str

@typing.type_check_only
class AnimationFade(typing_extensions.TypedDict, total=False):
    endTimeOffset: str
    fadeType: typing_extensions.Literal["FADE_TYPE_UNSPECIFIED", "FADE_IN", "FADE_OUT"]
    startTimeOffset: str
    xy: NormalizedCoordinate

@typing.type_check_only
class AnimationStatic(typing_extensions.TypedDict, total=False):
    startTimeOffset: str
    xy: NormalizedCoordinate

@typing.type_check_only
class Audio(typing_extensions.TypedDict, total=False):
    highBoost: bool
    lowBoost: bool
    lufs: float

@typing.type_check_only
class AudioAtom(typing_extensions.TypedDict, total=False):
    channels: _list[AudioChannel]
    key: str

@typing.type_check_only
class AudioChannel(typing_extensions.TypedDict, total=False):
    inputs: _list[AudioChannelInput]

@typing.type_check_only
class AudioChannelInput(typing_extensions.TypedDict, total=False):
    channel: int
    gainDb: float
    key: str
    track: int

@typing.type_check_only
class AudioStream(typing_extensions.TypedDict, total=False):
    bitrateBps: int
    channelCount: int
    channelLayout: _list[str]
    codec: str
    mapping: _list[AudioAtom]
    sampleRateHertz: int

@typing.type_check_only
class Color(typing_extensions.TypedDict, total=False):
    brightness: float
    contrast: float
    saturation: float

@typing.type_check_only
class Crop(typing_extensions.TypedDict, total=False):
    bottomPixels: int
    leftPixels: int
    rightPixels: int
    topPixels: int

@typing.type_check_only
class Deblock(typing_extensions.TypedDict, total=False):
    enabled: bool
    strength: float

@typing.type_check_only
class Denoise(typing_extensions.TypedDict, total=False):
    strength: float
    tune: str

@typing.type_check_only
class EditAtom(typing_extensions.TypedDict, total=False):
    endTimeOffset: str
    inputs: _list[str]
    key: str
    startTimeOffset: str

@typing.type_check_only
class ElementaryStream(typing_extensions.TypedDict, total=False):
    audioStream: AudioStream
    key: str
    textStream: TextStream
    videoStream: VideoStream

@typing.type_check_only
class Empty(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class Encryption(typing_extensions.TypedDict, total=False):
    aes128: Aes128Encryption
    iv: str
    key: str
    mpegCenc: MpegCommonEncryption
    sampleAes: SampleAesEncryption

@typing.type_check_only
class FailureDetail(typing_extensions.TypedDict, total=False):
    description: str

@typing.type_check_only
class Image(typing_extensions.TypedDict, total=False):
    alpha: float
    resolution: NormalizedCoordinate
    uri: str

@typing.type_check_only
class Input(typing_extensions.TypedDict, total=False):
    key: str
    preprocessingConfig: PreprocessingConfig
    uri: str

@typing.type_check_only
class Job(typing_extensions.TypedDict, total=False):
    config: JobConfig
    createTime: str
    endTime: str
    failureDetails: _list[FailureDetail]
    failureReason: str
    inputUri: str
    name: str
    originUri: OriginUri
    outputUri: str
    priority: int
    progress: Progress
    startTime: str
    state: typing_extensions.Literal[
        "PROCESSING_STATE_UNSPECIFIED", "PENDING", "RUNNING", "SUCCEEDED", "FAILED"
    ]
    templateId: str
    ttlAfterCompletionDays: int

@typing.type_check_only
class JobConfig(typing_extensions.TypedDict, total=False):
    adBreaks: _list[AdBreak]
    editList: _list[EditAtom]
    elementaryStreams: _list[ElementaryStream]
    inputs: _list[Input]
    manifests: _list[Manifest]
    muxStreams: _list[MuxStream]
    output: Output
    overlays: _list[Overlay]
    pubsubDestination: PubsubDestination
    spriteSheets: _list[SpriteSheet]

@typing.type_check_only
class JobTemplate(typing_extensions.TypedDict, total=False):
    config: JobConfig
    name: str

@typing.type_check_only
class ListJobTemplatesResponse(typing_extensions.TypedDict, total=False):
    jobTemplates: _list[JobTemplate]
    nextPageToken: str

@typing.type_check_only
class ListJobsResponse(typing_extensions.TypedDict, total=False):
    jobs: _list[Job]
    nextPageToken: str

@typing.type_check_only
class Manifest(typing_extensions.TypedDict, total=False):
    fileName: str
    muxStreams: _list[str]
    type: typing_extensions.Literal["MANIFEST_TYPE_UNSPECIFIED", "HLS", "DASH"]

@typing.type_check_only
class MpegCommonEncryption(typing_extensions.TypedDict, total=False):
    keyId: str
    scheme: str

@typing.type_check_only
class MuxStream(typing_extensions.TypedDict, total=False):
    container: str
    elementaryStreams: _list[str]
    encryption: Encryption
    fileName: str
    key: str
    segmentSettings: SegmentSettings

@typing.type_check_only
class NormalizedCoordinate(typing_extensions.TypedDict, total=False):
    x: float
    y: float

@typing.type_check_only
class OriginUri(typing_extensions.TypedDict, total=False):
    dash: str
    hls: str

@typing.type_check_only
class Output(typing_extensions.TypedDict, total=False):
    uri: str

@typing.type_check_only
class Overlay(typing_extensions.TypedDict, total=False):
    animations: _list[Animation]
    image: Image

@typing.type_check_only
class Pad(typing_extensions.TypedDict, total=False):
    bottomPixels: int
    leftPixels: int
    rightPixels: int
    topPixels: int

@typing.type_check_only
class PreprocessingConfig(typing_extensions.TypedDict, total=False):
    audio: Audio
    color: Color
    crop: Crop
    deblock: Deblock
    denoise: Denoise
    pad: Pad

@typing.type_check_only
class Progress(typing_extensions.TypedDict, total=False):
    analyzed: float
    encoded: float
    notified: float
    uploaded: float

@typing.type_check_only
class PubsubDestination(typing_extensions.TypedDict, total=False):
    topic: str

@typing.type_check_only
class SampleAesEncryption(typing_extensions.TypedDict, total=False):
    keyUri: str

@typing.type_check_only
class SegmentSettings(typing_extensions.TypedDict, total=False):
    individualSegments: bool
    segmentDuration: str

@typing.type_check_only
class SpriteSheet(typing_extensions.TypedDict, total=False):
    columnCount: int
    endTimeOffset: str
    filePrefix: str
    format: str
    interval: str
    quality: int
    rowCount: int
    spriteHeightPixels: int
    spriteWidthPixels: int
    startTimeOffset: str
    totalCount: int

@typing.type_check_only
class TextAtom(typing_extensions.TypedDict, total=False):
    inputs: _list[TextInput]
    key: str

@typing.type_check_only
class TextInput(typing_extensions.TypedDict, total=False):
    key: str
    track: int

@typing.type_check_only
class TextStream(typing_extensions.TypedDict, total=False):
    codec: str
    languageCode: str
    mapping: _list[TextAtom]

@typing.type_check_only
class VideoStream(typing_extensions.TypedDict, total=False):
    allowOpenGop: bool
    aqStrength: float
    bFrameCount: int
    bPyramid: bool
    bitrateBps: int
    codec: str
    crfLevel: int
    enableTwoPass: bool
    entropyCoder: str
    frameRate: float
    gopDuration: str
    gopFrameCount: int
    heightPixels: int
    pixelFormat: str
    preset: str
    profile: str
    rateControlMode: str
    tune: str
    vbvFullnessBits: int
    vbvSizeBits: int
    widthPixels: int



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class CloudIAPResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class V1beta1Resource(googleapiclient.discovery.Resource):
        def getIamPolicy(
            self,
            *,
            resource: str,
            body: GetIamPolicyRequest = ...,
            **kwargs: typing.Any
        ) -> PolicyHttpRequest: ...
        def setIamPolicy(
            self,
            *,
            resource: str,
            body: SetIamPolicyRequest = ...,
            **kwargs: typing.Any
        ) -> PolicyHttpRequest: ...
        def testIamPermissions(
            self,
            *,
            resource: str,
            body: TestIamPermissionsRequest = ...,
            **kwargs: typing.Any
        ) -> TestIamPermissionsResponseHttpRequest: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def v1beta1(self) -> V1beta1Resource: ...

@typing.type_check_only
class PolicyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Policy: ...

@typing.type_check_only
class TestIamPermissionsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> TestIamPermissionsResponse: ...



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class ConnectorsResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class ProjectsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class LocationsResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class ConnectionsResource(googleapiclient.discovery.Resource):
                @typing.type_check_only
                class RuntimeActionSchemasResource(googleapiclient.discovery.Resource):
                    def list(
                        self,
                        *,
                        parent: str,
                        filter: str = ...,
                        pageSize: int = ...,
                        pageToken: str = ...,
                        **kwargs: typing.Any
                    ) -> ListRuntimeActionSchemasResponseHttpRequest: ...
                    def list_next(
                        self,
                        previous_request: ListRuntimeActionSchemasResponseHttpRequest,
                        previous_response: ListRuntimeActionSchemasResponse,
                    ) -> ListRuntimeActionSchemasResponseHttpRequest | None: ...

                @typing.type_check_only
                class RuntimeEntitySchemasResource(googleapiclient.discovery.Resource):
                    def list(
                        self,
                        *,
                        parent: str,
                        filter: str = ...,
                        pageSize: int = ...,
                        pageToken: str = ...,
                        **kwargs: typing.Any
                    ) -> ListRuntimeEntitySchemasResponseHttpRequest: ...
                    def list_next(
                        self,
                        previous_request: ListRuntimeEntitySchemasResponseHttpRequest,
                        previous_response: ListRuntimeEntitySchemasResponse,
                    ) -> ListRuntimeEntitySchemasResponseHttpRequest | None: ...

                def create(
                    self,
                    *,
                    parent: str,
                    body: Connection = ...,
                    connectionId: str = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def delete(
                    self, *, name: str, **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def get(
                    self,
                    *,
                    name: str,
                    view: typing_extensions.Literal[
                        "CONNECTION_VIEW_UNSPECIFIED", "BASIC", "FULL"
                    ] = ...,
                    **kwargs: typing.Any
                ) -> ConnectionHttpRequest: ...
                def getConnectionSchemaMetadata(
                    self, *, name: str, **kwargs: typing.Any
                ) -> ConnectionSchemaMetadataHttpRequest: ...
                def getIamPolicy(
                    self,
                    *,
                    resource: str,
                    options_requestedPolicyVersion: int = ...,
                    **kwargs: typing.Any
                ) -> PolicyHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    filter: str = ...,
                    orderBy: str = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    view: typing_extensions.Literal[
                        "CONNECTION_VIEW_UNSPECIFIED", "BASIC", "FULL"
                    ] = ...,
                    **kwargs: typing.Any
                ) -> ListConnectionsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListConnectionsResponseHttpRequest,
                    previous_response: ListConnectionsResponse,
                ) -> ListConnectionsResponseHttpRequest | None: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: Connection = ...,
                    updateMask: str = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def setIamPolicy(
                    self,
                    *,
                    resource: str,
                    body: SetIamPolicyRequest = ...,
                    **kwargs: typing.Any
                ) -> PolicyHttpRequest: ...
                def testIamPermissions(
                    self,
                    *,
                    resource: str,
                    body: TestIamPermissionsRequest = ...,
                    **kwargs: typing.Any
                ) -> TestIamPermissionsResponseHttpRequest: ...
                def runtimeActionSchemas(self) -> RuntimeActionSchemasResource: ...
                def runtimeEntitySchemas(self) -> RuntimeEntitySchemasResource: ...

            @typing.type_check_only
            class OperationsResource(googleapiclient.discovery.Resource):
                def cancel(
                    self,
                    *,
                    name: str,
                    body: CancelOperationRequest = ...,
                    **kwargs: typing.Any
                ) -> EmptyHttpRequest: ...
                def delete(
                    self, *, name: str, **kwargs: typing.Any
                ) -> EmptyHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def list(
                    self,
                    *,
                    name: str,
                    filter: str = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListOperationsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListOperationsResponseHttpRequest,
                    previous_response: ListOperationsResponse,
                ) -> ListOperationsResponseHttpRequest | None: ...

            @typing.type_check_only
            class ProvidersResource(googleapiclient.discovery.Resource):
                @typing.type_check_only
                class ConnectorsResource(googleapiclient.discovery.Resource):
                    @typing.type_check_only
                    class VersionsResource(googleapiclient.discovery.Resource):
                        def get(
                            self,
                            *,
                            name: str,
                            view: typing_extensions.Literal[
                                "CONNECTOR_VERSION_VIEW_UNSPECIFIED",
                                "CONNECTOR_VERSION_VIEW_BASIC",
                                "CONNECTOR_VERSION_VIEW_FULL",
                            ] = ...,
                            **kwargs: typing.Any
                        ) -> ConnectorVersionHttpRequest: ...
                        def list(
                            self,
                            *,
                            parent: str,
                            pageSize: int = ...,
                            pageToken: str = ...,
                            view: typing_extensions.Literal[
                                "CONNECTOR_VERSION_VIEW_UNSPECIFIED",
                                "CONNECTOR_VERSION_VIEW_BASIC",
                                "CONNECTOR_VERSION_VIEW_FULL",
                            ] = ...,
                            **kwargs: typing.Any
                        ) -> ListConnectorVersionsResponseHttpRequest: ...
                        def list_next(
                            self,
                            previous_request: ListConnectorVersionsResponseHttpRequest,
                            previous_response: ListConnectorVersionsResponse,
                        ) -> ListConnectorVersionsResponseHttpRequest | None: ...

                    def get(
                        self, *, name: str, **kwargs: typing.Any
                    ) -> ConnectorHttpRequest: ...
                    def list(
                        self,
                        *,
                        parent: str,
                        pageSize: int = ...,
                        pageToken: str = ...,
                        **kwargs: typing.Any
                    ) -> ListConnectorsResponseHttpRequest: ...
                    def list_next(
                        self,
                        previous_request: ListConnectorsResponseHttpRequest,
                        previous_response: ListConnectorsResponse,
                    ) -> ListConnectorsResponseHttpRequest | None: ...
                    def versions(self) -> VersionsResource: ...

                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> ProviderHttpRequest: ...
                def getIamPolicy(
                    self,
                    *,
                    resource: str,
                    options_requestedPolicyVersion: int = ...,
                    **kwargs: typing.Any
                ) -> PolicyHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListProvidersResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListProvidersResponseHttpRequest,
                    previous_response: ListProvidersResponse,
                ) -> ListProvidersResponseHttpRequest | None: ...
                def setIamPolicy(
                    self,
                    *,
                    resource: str,
                    body: SetIamPolicyRequest = ...,
                    **kwargs: typing.Any
                ) -> PolicyHttpRequest: ...
                def testIamPermissions(
                    self,
                    *,
                    resource: str,
                    body: TestIamPermissionsRequest = ...,
                    **kwargs: typing.Any
                ) -> TestIamPermissionsResponseHttpRequest: ...
                def connectors(self) -> ConnectorsResource: ...

            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> LocationHttpRequest: ...
            def getRuntimeConfig(
                self, *, name: str, **kwargs: typing.Any
            ) -> RuntimeConfigHttpRequest: ...
            def list(
                self,
                *,
                name: str,
                filter: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListLocationsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListLocationsResponseHttpRequest,
                previous_response: ListLocationsResponse,
            ) -> ListLocationsResponseHttpRequest | None: ...
            def connections(self) -> ConnectionsResource: ...
            def operations(self) -> OperationsResource: ...
            def providers(self) -> ProvidersResource: ...

        def locations(self) -> LocationsResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def projects(self) -> ProjectsResource: ...

@typing.type_check_only
class ConnectionHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Connection: ...

@typing.type_check_only
class ConnectionSchemaMetadataHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ConnectionSchemaMetadata: ...

@typing.type_check_only
class ConnectorHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Connector: ...

@typing.type_check_only
class ConnectorVersionHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ConnectorVersion: ...

@typing.type_check_only
class EmptyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Empty: ...

@typing.type_check_only
class ListConnectionsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListConnectionsResponse: ...

@typing.type_check_only
class ListConnectorVersionsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListConnectorVersionsResponse: ...

@typing.type_check_only
class ListConnectorsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListConnectorsResponse: ...

@typing.type_check_only
class ListLocationsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListLocationsResponse: ...

@typing.type_check_only
class ListOperationsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListOperationsResponse: ...

@typing.type_check_only
class ListProvidersResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListProvidersResponse: ...

@typing.type_check_only
class ListRuntimeActionSchemasResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListRuntimeActionSchemasResponse: ...

@typing.type_check_only
class ListRuntimeEntitySchemasResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListRuntimeEntitySchemasResponse: ...

@typing.type_check_only
class LocationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Location: ...

@typing.type_check_only
class OperationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Operation: ...

@typing.type_check_only
class PolicyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Policy: ...

@typing.type_check_only
class ProviderHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Provider: ...

@typing.type_check_only
class RuntimeConfigHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> RuntimeConfig: ...

@typing.type_check_only
class TestIamPermissionsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> TestIamPermissionsResponse: ...



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class IdentityToolkitResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class AccountsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class MfaEnrollmentResource(googleapiclient.discovery.Resource):
            def finalize(
                self,
                *,
                body: GoogleCloudIdentitytoolkitV2FinalizeMfaEnrollmentRequest = ...,
                **kwargs: typing.Any
            ) -> GoogleCloudIdentitytoolkitV2FinalizeMfaEnrollmentResponseHttpRequest: ...
            def start(
                self,
                *,
                body: GoogleCloudIdentitytoolkitV2StartMfaEnrollmentRequest = ...,
                **kwargs: typing.Any
            ) -> GoogleCloudIdentitytoolkitV2StartMfaEnrollmentResponseHttpRequest: ...
            def withdraw(
                self,
                *,
                body: GoogleCloudIdentitytoolkitV2WithdrawMfaRequest = ...,
                **kwargs: typing.Any
            ) -> GoogleCloudIdentitytoolkitV2WithdrawMfaResponseHttpRequest: ...

        @typing.type_check_only
        class MfaSignInResource(googleapiclient.discovery.Resource):
            def finalize(
                self,
                *,
                body: GoogleCloudIdentitytoolkitV2FinalizeMfaSignInRequest = ...,
                **kwargs: typing.Any
            ) -> GoogleCloudIdentitytoolkitV2FinalizeMfaSignInResponseHttpRequest: ...
            def start(
                self,
                *,
                body: GoogleCloudIdentitytoolkitV2StartMfaSignInRequest = ...,
                **kwargs: typing.Any
            ) -> GoogleCloudIdentitytoolkitV2StartMfaSignInResponseHttpRequest: ...

        def mfaEnrollment(self) -> MfaEnrollmentResource: ...
        def mfaSignIn(self) -> MfaSignInResource: ...

    @typing.type_check_only
    class DefaultSupportedIdpsResource(googleapiclient.discovery.Resource):
        def list(
            self, *, pageSize: int = ..., pageToken: str = ..., **kwargs: typing.Any
        ) -> GoogleCloudIdentitytoolkitAdminV2ListDefaultSupportedIdpsResponseHttpRequest: ...
        def list_next(
            self,
            previous_request: GoogleCloudIdentitytoolkitAdminV2ListDefaultSupportedIdpsResponseHttpRequest,
            previous_response: GoogleCloudIdentitytoolkitAdminV2ListDefaultSupportedIdpsResponse,
        ) -> GoogleCloudIdentitytoolkitAdminV2ListDefaultSupportedIdpsResponseHttpRequest | None: ...

    @typing.type_check_only
    class ProjectsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class DefaultSupportedIdpConfigsResource(googleapiclient.discovery.Resource):
            def create(
                self,
                *,
                parent: str,
                body: GoogleCloudIdentitytoolkitAdminV2DefaultSupportedIdpConfig = ...,
                idpId: str = ...,
                **kwargs: typing.Any
            ) -> GoogleCloudIdentitytoolkitAdminV2DefaultSupportedIdpConfigHttpRequest: ...
            def delete(
                self, *, name: str, **kwargs: typing.Any
            ) -> GoogleProtobufEmptyHttpRequest: ...
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> GoogleCloudIdentitytoolkitAdminV2DefaultSupportedIdpConfigHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> GoogleCloudIdentitytoolkitAdminV2ListDefaultSupportedIdpConfigsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: GoogleCloudIdentitytoolkitAdminV2ListDefaultSupportedIdpConfigsResponseHttpRequest,
                previous_response: GoogleCloudIdentitytoolkitAdminV2ListDefaultSupportedIdpConfigsResponse,
            ) -> GoogleCloudIdentitytoolkitAdminV2ListDefaultSupportedIdpConfigsResponseHttpRequest | None: ...
            def patch(
                self,
                *,
                name: str,
                body: GoogleCloudIdentitytoolkitAdminV2DefaultSupportedIdpConfig = ...,
                updateMask: str = ...,
                **kwargs: typing.Any
            ) -> GoogleCloudIdentitytoolkitAdminV2DefaultSupportedIdpConfigHttpRequest: ...

        @typing.type_check_only
        class IdentityPlatformResource(googleapiclient.discovery.Resource):
            def initializeAuth(
                self,
                *,
                project: str,
                body: GoogleCloudIdentitytoolkitAdminV2InitializeIdentityPlatformRequest = ...,
                **kwargs: typing.Any
            ) -> GoogleCloudIdentitytoolkitAdminV2InitializeIdentityPlatformResponseHttpRequest: ...

        @typing.type_check_only
        class InboundSamlConfigsResource(googleapiclient.discovery.Resource):
            def create(
                self,
                *,
                parent: str,
                body: GoogleCloudIdentitytoolkitAdminV2InboundSamlConfig = ...,
                inboundSamlConfigId: str = ...,
                **kwargs: typing.Any
            ) -> GoogleCloudIdentitytoolkitAdminV2InboundSamlConfigHttpRequest: ...
            def delete(
                self, *, name: str, **kwargs: typing.Any
            ) -> GoogleProtobufEmptyHttpRequest: ...
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> GoogleCloudIdentitytoolkitAdminV2InboundSamlConfigHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> GoogleCloudIdentitytoolkitAdminV2ListInboundSamlConfigsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: GoogleCloudIdentitytoolkitAdminV2ListInboundSamlConfigsResponseHttpRequest,
                previous_response: GoogleCloudIdentitytoolkitAdminV2ListInboundSamlConfigsResponse,
            ) -> GoogleCloudIdentitytoolkitAdminV2ListInboundSamlConfigsResponseHttpRequest | None: ...
            def patch(
                self,
                *,
                name: str,
                body: GoogleCloudIdentitytoolkitAdminV2InboundSamlConfig = ...,
                updateMask: str = ...,
                **kwargs: typing.Any
            ) -> GoogleCloudIdentitytoolkitAdminV2InboundSamlConfigHttpRequest: ...

        @typing.type_check_only
        class OauthIdpConfigsResource(googleapiclient.discovery.Resource):
            def create(
                self,
                *,
                parent: str,
                body: GoogleCloudIdentitytoolkitAdminV2OAuthIdpConfig = ...,
                oauthIdpConfigId: str = ...,
                **kwargs: typing.Any
            ) -> GoogleCloudIdentitytoolkitAdminV2OAuthIdpConfigHttpRequest: ...
            def delete(
                self, *, name: str, **kwargs: typing.Any
            ) -> GoogleProtobufEmptyHttpRequest: ...
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> GoogleCloudIdentitytoolkitAdminV2OAuthIdpConfigHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> GoogleCloudIdentitytoolkitAdminV2ListOAuthIdpConfigsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: GoogleCloudIdentitytoolkitAdminV2ListOAuthIdpConfigsResponseHttpRequest,
                previous_response: GoogleCloudIdentitytoolkitAdminV2ListOAuthIdpConfigsResponse,
            ) -> GoogleCloudIdentitytoolkitAdminV2ListOAuthIdpConfigsResponseHttpRequest | None: ...
            def patch(
                self,
                *,
                name: str,
                body: GoogleCloudIdentitytoolkitAdminV2OAuthIdpConfig = ...,
                updateMask: str = ...,
                **kwargs: typing.Any
            ) -> GoogleCloudIdentitytoolkitAdminV2OAuthIdpConfigHttpRequest: ...

        @typing.type_check_only
        class TenantsResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class DefaultSupportedIdpConfigsResource(
                googleapiclient.discovery.Resource
            ):
                def create(
                    self,
                    *,
                    parent: str,
                    body: GoogleCloudIdentitytoolkitAdminV2DefaultSupportedIdpConfig = ...,
                    idpId: str = ...,
                    **kwargs: typing.Any
                ) -> GoogleCloudIdentitytoolkitAdminV2DefaultSupportedIdpConfigHttpRequest: ...
                def delete(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GoogleProtobufEmptyHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GoogleCloudIdentitytoolkitAdminV2DefaultSupportedIdpConfigHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> GoogleCloudIdentitytoolkitAdminV2ListDefaultSupportedIdpConfigsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: GoogleCloudIdentitytoolkitAdminV2ListDefaultSupportedIdpConfigsResponseHttpRequest,
                    previous_response: GoogleCloudIdentitytoolkitAdminV2ListDefaultSupportedIdpConfigsResponse,
                ) -> GoogleCloudIdentitytoolkitAdminV2ListDefaultSupportedIdpConfigsResponseHttpRequest | None: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: GoogleCloudIdentitytoolkitAdminV2DefaultSupportedIdpConfig = ...,
                    updateMask: str = ...,
                    **kwargs: typing.Any
                ) -> GoogleCloudIdentitytoolkitAdminV2DefaultSupportedIdpConfigHttpRequest: ...

            @typing.type_check_only
            class InboundSamlConfigsResource(googleapiclient.discovery.Resource):
                def create(
                    self,
                    *,
                    parent: str,
                    body: GoogleCloudIdentitytoolkitAdminV2InboundSamlConfig = ...,
                    inboundSamlConfigId: str = ...,
                    **kwargs: typing.Any
                ) -> GoogleCloudIdentitytoolkitAdminV2InboundSamlConfigHttpRequest: ...
                def delete(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GoogleProtobufEmptyHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GoogleCloudIdentitytoolkitAdminV2InboundSamlConfigHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> GoogleCloudIdentitytoolkitAdminV2ListInboundSamlConfigsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: GoogleCloudIdentitytoolkitAdminV2ListInboundSamlConfigsResponseHttpRequest,
                    previous_response: GoogleCloudIdentitytoolkitAdminV2ListInboundSamlConfigsResponse,
                ) -> GoogleCloudIdentitytoolkitAdminV2ListInboundSamlConfigsResponseHttpRequest | None: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: GoogleCloudIdentitytoolkitAdminV2InboundSamlConfig = ...,
                    updateMask: str = ...,
                    **kwargs: typing.Any
                ) -> GoogleCloudIdentitytoolkitAdminV2InboundSamlConfigHttpRequest: ...

            @typing.type_check_only
            class OauthIdpConfigsResource(googleapiclient.discovery.Resource):
                def create(
                    self,
                    *,
                    parent: str,
                    body: GoogleCloudIdentitytoolkitAdminV2OAuthIdpConfig = ...,
                    oauthIdpConfigId: str = ...,
                    **kwargs: typing.Any
                ) -> GoogleCloudIdentitytoolkitAdminV2OAuthIdpConfigHttpRequest: ...
                def delete(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GoogleProtobufEmptyHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GoogleCloudIdentitytoolkitAdminV2OAuthIdpConfigHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> GoogleCloudIdentitytoolkitAdminV2ListOAuthIdpConfigsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: GoogleCloudIdentitytoolkitAdminV2ListOAuthIdpConfigsResponseHttpRequest,
                    previous_response: GoogleCloudIdentitytoolkitAdminV2ListOAuthIdpConfigsResponse,
                ) -> GoogleCloudIdentitytoolkitAdminV2ListOAuthIdpConfigsResponseHttpRequest | None: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: GoogleCloudIdentitytoolkitAdminV2OAuthIdpConfig = ...,
                    updateMask: str = ...,
                    **kwargs: typing.Any
                ) -> GoogleCloudIdentitytoolkitAdminV2OAuthIdpConfigHttpRequest: ...

            def create(
                self,
                *,
                parent: str,
                body: GoogleCloudIdentitytoolkitAdminV2Tenant = ...,
                **kwargs: typing.Any
            ) -> GoogleCloudIdentitytoolkitAdminV2TenantHttpRequest: ...
            def delete(
                self, *, name: str, **kwargs: typing.Any
            ) -> GoogleProtobufEmptyHttpRequest: ...
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> GoogleCloudIdentitytoolkitAdminV2TenantHttpRequest: ...
            def getIamPolicy(
                self,
                *,
                resource: str,
                body: GoogleIamV1GetIamPolicyRequest = ...,
                **kwargs: typing.Any
            ) -> GoogleIamV1PolicyHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> GoogleCloudIdentitytoolkitAdminV2ListTenantsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: GoogleCloudIdentitytoolkitAdminV2ListTenantsResponseHttpRequest,
                previous_response: GoogleCloudIdentitytoolkitAdminV2ListTenantsResponse,
            ) -> GoogleCloudIdentitytoolkitAdminV2ListTenantsResponseHttpRequest | None: ...
            def patch(
                self,
                *,
                name: str,
                body: GoogleCloudIdentitytoolkitAdminV2Tenant = ...,
                updateMask: str = ...,
                **kwargs: typing.Any
            ) -> GoogleCloudIdentitytoolkitAdminV2TenantHttpRequest: ...
            def setIamPolicy(
                self,
                *,
                resource: str,
                body: GoogleIamV1SetIamPolicyRequest = ...,
                **kwargs: typing.Any
            ) -> GoogleIamV1PolicyHttpRequest: ...
            def testIamPermissions(
                self,
                *,
                resource: str,
                body: GoogleIamV1TestIamPermissionsRequest = ...,
                **kwargs: typing.Any
            ) -> GoogleIamV1TestIamPermissionsResponseHttpRequest: ...
            def defaultSupportedIdpConfigs(
                self,
            ) -> DefaultSupportedIdpConfigsResource: ...
            def inboundSamlConfigs(self) -> InboundSamlConfigsResource: ...
            def oauthIdpConfigs(self) -> OauthIdpConfigsResource: ...

        def getConfig(
            self, *, name: str, **kwargs: typing.Any
        ) -> GoogleCloudIdentitytoolkitAdminV2ConfigHttpRequest: ...
        def updateConfig(
            self,
            *,
            name: str,
            body: GoogleCloudIdentitytoolkitAdminV2Config = ...,
            updateMask: str = ...,
            **kwargs: typing.Any
        ) -> GoogleCloudIdentitytoolkitAdminV2ConfigHttpRequest: ...
        def defaultSupportedIdpConfigs(self) -> DefaultSupportedIdpConfigsResource: ...
        def identityPlatform(self) -> IdentityPlatformResource: ...
        def inboundSamlConfigs(self) -> InboundSamlConfigsResource: ...
        def oauthIdpConfigs(self) -> OauthIdpConfigsResource: ...
        def tenants(self) -> TenantsResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def accounts(self) -> AccountsResource: ...
    def defaultSupportedIdps(self) -> DefaultSupportedIdpsResource: ...
    def projects(self) -> ProjectsResource: ...

@typing.type_check_only
class GoogleCloudIdentitytoolkitAdminV2ConfigHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudIdentitytoolkitAdminV2Config: ...

@typing.type_check_only
class GoogleCloudIdentitytoolkitAdminV2DefaultSupportedIdpConfigHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudIdentitytoolkitAdminV2DefaultSupportedIdpConfig: ...

@typing.type_check_only
class GoogleCloudIdentitytoolkitAdminV2InboundSamlConfigHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudIdentitytoolkitAdminV2InboundSamlConfig: ...

@typing.type_check_only
class GoogleCloudIdentitytoolkitAdminV2InitializeIdentityPlatformResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudIdentitytoolkitAdminV2InitializeIdentityPlatformResponse: ...

@typing.type_check_only
class GoogleCloudIdentitytoolkitAdminV2ListDefaultSupportedIdpConfigsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudIdentitytoolkitAdminV2ListDefaultSupportedIdpConfigsResponse: ...

@typing.type_check_only
class GoogleCloudIdentitytoolkitAdminV2ListDefaultSupportedIdpsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudIdentitytoolkitAdminV2ListDefaultSupportedIdpsResponse: ...

@typing.type_check_only
class GoogleCloudIdentitytoolkitAdminV2ListInboundSamlConfigsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudIdentitytoolkitAdminV2ListInboundSamlConfigsResponse: ...

@typing.type_check_only
class GoogleCloudIdentitytoolkitAdminV2ListOAuthIdpConfigsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudIdentitytoolkitAdminV2ListOAuthIdpConfigsResponse: ...

@typing.type_check_only
class GoogleCloudIdentitytoolkitAdminV2ListTenantsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudIdentitytoolkitAdminV2ListTenantsResponse: ...

@typing.type_check_only
class GoogleCloudIdentitytoolkitAdminV2OAuthIdpConfigHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudIdentitytoolkitAdminV2OAuthIdpConfig: ...

@typing.type_check_only
class GoogleCloudIdentitytoolkitAdminV2TenantHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudIdentitytoolkitAdminV2Tenant: ...

@typing.type_check_only
class GoogleCloudIdentitytoolkitV2FinalizeMfaEnrollmentResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudIdentitytoolkitV2FinalizeMfaEnrollmentResponse: ...

@typing.type_check_only
class GoogleCloudIdentitytoolkitV2FinalizeMfaSignInResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudIdentitytoolkitV2FinalizeMfaSignInResponse: ...

@typing.type_check_only
class GoogleCloudIdentitytoolkitV2StartMfaEnrollmentResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudIdentitytoolkitV2StartMfaEnrollmentResponse: ...

@typing.type_check_only
class GoogleCloudIdentitytoolkitV2StartMfaSignInResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudIdentitytoolkitV2StartMfaSignInResponse: ...

@typing.type_check_only
class GoogleCloudIdentitytoolkitV2WithdrawMfaResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudIdentitytoolkitV2WithdrawMfaResponse: ...

@typing.type_check_only
class GoogleIamV1PolicyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleIamV1Policy: ...

@typing.type_check_only
class GoogleIamV1TestIamPermissionsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleIamV1TestIamPermissionsResponse: ...

@typing.type_check_only
class GoogleProtobufEmptyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleProtobufEmpty: ...



import typing

import typing_extensions

_list = list

@typing.type_check_only
class AggregateBucket(typing_extensions.TypedDict, total=False):
    activity: int
    dataset: _list[Dataset]
    endTimeMillis: str
    session: Session
    startTimeMillis: str
    type: typing_extensions.Literal[
        "unknown", "time", "session", "activityType", "activitySegment"
    ]

@typing.type_check_only
class AggregateBy(typing_extensions.TypedDict, total=False):
    dataSourceId: str
    dataTypeName: str

@typing.type_check_only
class AggregateRequest(typing_extensions.TypedDict, total=False):
    aggregateBy: _list[AggregateBy]
    bucketByActivitySegment: BucketByActivity
    bucketByActivityType: BucketByActivity
    bucketBySession: BucketBySession
    bucketByTime: BucketByTime
    endTimeMillis: str
    filteredDataQualityStandard: _list[str]
    startTimeMillis: str

@typing.type_check_only
class AggregateResponse(typing_extensions.TypedDict, total=False):
    bucket: _list[AggregateBucket]

@typing.type_check_only
class Application(typing_extensions.TypedDict, total=False):
    detailsUrl: str
    name: str
    packageName: str
    version: str

@typing.type_check_only
class BucketByActivity(typing_extensions.TypedDict, total=False):
    activityDataSourceId: str
    minDurationMillis: str

@typing.type_check_only
class BucketBySession(typing_extensions.TypedDict, total=False):
    minDurationMillis: str

@typing.type_check_only
class BucketByTime(typing_extensions.TypedDict, total=False):
    durationMillis: str
    period: BucketByTimePeriod

@typing.type_check_only
class BucketByTimePeriod(typing_extensions.TypedDict, total=False):
    timeZoneId: str
    type: typing_extensions.Literal["day", "week", "month"]
    value: int

@typing.type_check_only
class DataPoint(typing_extensions.TypedDict, total=False):
    computationTimeMillis: str
    dataTypeName: str
    endTimeNanos: str
    modifiedTimeMillis: str
    originDataSourceId: str
    rawTimestampNanos: str
    startTimeNanos: str
    value: _list[Value]

@typing.type_check_only
class DataSource(typing_extensions.TypedDict, total=False):
    application: Application
    dataQualityStandard: _list[str]
    dataStreamId: str
    dataStreamName: str
    dataType: DataType
    device: Device
    name: str
    type: typing_extensions.Literal["raw", "derived"]

@typing.type_check_only
class DataType(typing_extensions.TypedDict, total=False):
    field: _list[DataTypeField]
    name: str

@typing.type_check_only
class DataTypeField(typing_extensions.TypedDict, total=False):
    format: typing_extensions.Literal[
        "integer", "floatPoint", "string", "map", "integerList", "floatList", "blob"
    ]
    name: str
    optional: bool

@typing.type_check_only
class Dataset(typing_extensions.TypedDict, total=False):
    dataSourceId: str
    maxEndTimeNs: str
    minStartTimeNs: str
    nextPageToken: str
    point: _list[DataPoint]

@typing.type_check_only
class Device(typing_extensions.TypedDict, total=False):
    manufacturer: str
    model: str
    type: typing_extensions.Literal[
        "unknown",
        "phone",
        "tablet",
        "watch",
        "chestStrap",
        "scale",
        "headMounted",
        "smartDisplay",
    ]
    uid: str
    version: str

@typing.type_check_only
class ListDataPointChangesResponse(typing_extensions.TypedDict, total=False):
    dataSourceId: str
    deletedDataPoint: _list[DataPoint]
    insertedDataPoint: _list[DataPoint]
    nextPageToken: str

@typing.type_check_only
class ListDataSourcesResponse(typing_extensions.TypedDict, total=False):
    dataSource: _list[DataSource]

@typing.type_check_only
class ListSessionsResponse(typing_extensions.TypedDict, total=False):
    deletedSession: _list[Session]
    hasMoreData: bool
    nextPageToken: str
    session: _list[Session]

@typing.type_check_only
class MapValue(typing_extensions.TypedDict, total=False):
    fpVal: float

@typing.type_check_only
class Session(typing_extensions.TypedDict, total=False):
    activeTimeMillis: str
    activityType: int
    application: Application
    description: str
    endTimeMillis: str
    id: str
    modifiedTimeMillis: str
    name: str
    startTimeMillis: str

@typing.type_check_only
class Value(typing_extensions.TypedDict, total=False):
    fpVal: float
    intVal: int
    mapVal: _list[ValueMapValEntry]
    stringVal: str

@typing.type_check_only
class ValueMapValEntry(typing_extensions.TypedDict, total=False):
    key: str
    value: MapValue



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class DLPResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class InfoTypesResource(googleapiclient.discovery.Resource):
        def list(
            self,
            *,
            filter: str = ...,
            languageCode: str = ...,
            locationId: str = ...,
            parent: str = ...,
            **kwargs: typing.Any
        ) -> GooglePrivacyDlpV2ListInfoTypesResponseHttpRequest: ...

    @typing.type_check_only
    class LocationsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class InfoTypesResource(googleapiclient.discovery.Resource):
            def list(
                self,
                *,
                parent: str,
                filter: str = ...,
                languageCode: str = ...,
                locationId: str = ...,
                **kwargs: typing.Any
            ) -> GooglePrivacyDlpV2ListInfoTypesResponseHttpRequest: ...

        def infoTypes(self) -> InfoTypesResource: ...

    @typing.type_check_only
    class OrganizationsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class DeidentifyTemplatesResource(googleapiclient.discovery.Resource):
            def create(
                self,
                *,
                parent: str,
                body: GooglePrivacyDlpV2CreateDeidentifyTemplateRequest = ...,
                **kwargs: typing.Any
            ) -> GooglePrivacyDlpV2DeidentifyTemplateHttpRequest: ...
            def delete(
                self, *, name: str, **kwargs: typing.Any
            ) -> GoogleProtobufEmptyHttpRequest: ...
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> GooglePrivacyDlpV2DeidentifyTemplateHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                locationId: str = ...,
                orderBy: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> GooglePrivacyDlpV2ListDeidentifyTemplatesResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: GooglePrivacyDlpV2ListDeidentifyTemplatesResponseHttpRequest,
                previous_response: GooglePrivacyDlpV2ListDeidentifyTemplatesResponse,
            ) -> GooglePrivacyDlpV2ListDeidentifyTemplatesResponseHttpRequest | None: ...
            def patch(
                self,
                *,
                name: str,
                body: GooglePrivacyDlpV2UpdateDeidentifyTemplateRequest = ...,
                **kwargs: typing.Any
            ) -> GooglePrivacyDlpV2DeidentifyTemplateHttpRequest: ...

        @typing.type_check_only
        class InspectTemplatesResource(googleapiclient.discovery.Resource):
            def create(
                self,
                *,
                parent: str,
                body: GooglePrivacyDlpV2CreateInspectTemplateRequest = ...,
                **kwargs: typing.Any
            ) -> GooglePrivacyDlpV2InspectTemplateHttpRequest: ...
            def delete(
                self, *, name: str, **kwargs: typing.Any
            ) -> GoogleProtobufEmptyHttpRequest: ...
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> GooglePrivacyDlpV2InspectTemplateHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                locationId: str = ...,
                orderBy: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> GooglePrivacyDlpV2ListInspectTemplatesResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: GooglePrivacyDlpV2ListInspectTemplatesResponseHttpRequest,
                previous_response: GooglePrivacyDlpV2ListInspectTemplatesResponse,
            ) -> GooglePrivacyDlpV2ListInspectTemplatesResponseHttpRequest | None: ...
            def patch(
                self,
                *,
                name: str,
                body: GooglePrivacyDlpV2UpdateInspectTemplateRequest = ...,
                **kwargs: typing.Any
            ) -> GooglePrivacyDlpV2InspectTemplateHttpRequest: ...

        @typing.type_check_only
        class LocationsResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class DeidentifyTemplatesResource(googleapiclient.discovery.Resource):
                def create(
                    self,
                    *,
                    parent: str,
                    body: GooglePrivacyDlpV2CreateDeidentifyTemplateRequest = ...,
                    **kwargs: typing.Any
                ) -> GooglePrivacyDlpV2DeidentifyTemplateHttpRequest: ...
                def delete(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GoogleProtobufEmptyHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GooglePrivacyDlpV2DeidentifyTemplateHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    locationId: str = ...,
                    orderBy: str = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> GooglePrivacyDlpV2ListDeidentifyTemplatesResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: GooglePrivacyDlpV2ListDeidentifyTemplatesResponseHttpRequest,
                    previous_response: GooglePrivacyDlpV2ListDeidentifyTemplatesResponse,
                ) -> GooglePrivacyDlpV2ListDeidentifyTemplatesResponseHttpRequest | None: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: GooglePrivacyDlpV2UpdateDeidentifyTemplateRequest = ...,
                    **kwargs: typing.Any
                ) -> GooglePrivacyDlpV2DeidentifyTemplateHttpRequest: ...

            @typing.type_check_only
            class DlpJobsResource(googleapiclient.discovery.Resource):
                def list(
                    self,
                    *,
                    parent: str,
                    filter: str = ...,
                    locationId: str = ...,
                    orderBy: str = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    type: typing_extensions.Literal[
                        "DLP_JOB_TYPE_UNSPECIFIED", "INSPECT_JOB", "RISK_ANALYSIS_JOB"
                    ] = ...,
                    **kwargs: typing.Any
                ) -> GooglePrivacyDlpV2ListDlpJobsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: GooglePrivacyDlpV2ListDlpJobsResponseHttpRequest,
                    previous_response: GooglePrivacyDlpV2ListDlpJobsResponse,
                ) -> GooglePrivacyDlpV2ListDlpJobsResponseHttpRequest | None: ...

            @typing.type_check_only
            class InspectTemplatesResource(googleapiclient.discovery.Resource):
                def create(
                    self,
                    *,
                    parent: str,
                    body: GooglePrivacyDlpV2CreateInspectTemplateRequest = ...,
                    **kwargs: typing.Any
                ) -> GooglePrivacyDlpV2InspectTemplateHttpRequest: ...
                def delete(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GoogleProtobufEmptyHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GooglePrivacyDlpV2InspectTemplateHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    locationId: str = ...,
                    orderBy: str = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> GooglePrivacyDlpV2ListInspectTemplatesResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: GooglePrivacyDlpV2ListInspectTemplatesResponseHttpRequest,
                    previous_response: GooglePrivacyDlpV2ListInspectTemplatesResponse,
                ) -> GooglePrivacyDlpV2ListInspectTemplatesResponseHttpRequest | None: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: GooglePrivacyDlpV2UpdateInspectTemplateRequest = ...,
                    **kwargs: typing.Any
                ) -> GooglePrivacyDlpV2InspectTemplateHttpRequest: ...

            @typing.type_check_only
            class JobTriggersResource(googleapiclient.discovery.Resource):
                def create(
                    self,
                    *,
                    parent: str,
                    body: GooglePrivacyDlpV2CreateJobTriggerRequest = ...,
                    **kwargs: typing.Any
                ) -> GooglePrivacyDlpV2JobTriggerHttpRequest: ...
                def delete(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GoogleProtobufEmptyHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GooglePrivacyDlpV2JobTriggerHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    filter: str = ...,
                    locationId: str = ...,
                    orderBy: str = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    type: typing_extensions.Literal[
                        "DLP_JOB_TYPE_UNSPECIFIED", "INSPECT_JOB", "RISK_ANALYSIS_JOB"
                    ] = ...,
                    **kwargs: typing.Any
                ) -> GooglePrivacyDlpV2ListJobTriggersResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: GooglePrivacyDlpV2ListJobTriggersResponseHttpRequest,
                    previous_response: GooglePrivacyDlpV2ListJobTriggersResponse,
                ) -> GooglePrivacyDlpV2ListJobTriggersResponseHttpRequest | None: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: GooglePrivacyDlpV2UpdateJobTriggerRequest = ...,
                    **kwargs: typing.Any
                ) -> GooglePrivacyDlpV2JobTriggerHttpRequest: ...

            @typing.type_check_only
            class StoredInfoTypesResource(googleapiclient.discovery.Resource):
                def create(
                    self,
                    *,
                    parent: str,
                    body: GooglePrivacyDlpV2CreateStoredInfoTypeRequest = ...,
                    **kwargs: typing.Any
                ) -> GooglePrivacyDlpV2StoredInfoTypeHttpRequest: ...
                def delete(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GoogleProtobufEmptyHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GooglePrivacyDlpV2StoredInfoTypeHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    locationId: str = ...,
                    orderBy: str = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> GooglePrivacyDlpV2ListStoredInfoTypesResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: GooglePrivacyDlpV2ListStoredInfoTypesResponseHttpRequest,
                    previous_response: GooglePrivacyDlpV2ListStoredInfoTypesResponse,
                ) -> GooglePrivacyDlpV2ListStoredInfoTypesResponseHttpRequest | None: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: GooglePrivacyDlpV2UpdateStoredInfoTypeRequest = ...,
                    **kwargs: typing.Any
                ) -> GooglePrivacyDlpV2StoredInfoTypeHttpRequest: ...

            def deidentifyTemplates(self) -> DeidentifyTemplatesResource: ...
            def dlpJobs(self) -> DlpJobsResource: ...
            def inspectTemplates(self) -> InspectTemplatesResource: ...
            def jobTriggers(self) -> JobTriggersResource: ...
            def storedInfoTypes(self) -> StoredInfoTypesResource: ...

        @typing.type_check_only
        class StoredInfoTypesResource(googleapiclient.discovery.Resource):
            def create(
                self,
                *,
                parent: str,
                body: GooglePrivacyDlpV2CreateStoredInfoTypeRequest = ...,
                **kwargs: typing.Any
            ) -> GooglePrivacyDlpV2StoredInfoTypeHttpRequest: ...
            def delete(
                self, *, name: str, **kwargs: typing.Any
            ) -> GoogleProtobufEmptyHttpRequest: ...
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> GooglePrivacyDlpV2StoredInfoTypeHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                locationId: str = ...,
                orderBy: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> GooglePrivacyDlpV2ListStoredInfoTypesResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: GooglePrivacyDlpV2ListStoredInfoTypesResponseHttpRequest,
                previous_response: GooglePrivacyDlpV2ListStoredInfoTypesResponse,
            ) -> GooglePrivacyDlpV2ListStoredInfoTypesResponseHttpRequest | None: ...
            def patch(
                self,
                *,
                name: str,
                body: GooglePrivacyDlpV2UpdateStoredInfoTypeRequest = ...,
                **kwargs: typing.Any
            ) -> GooglePrivacyDlpV2StoredInfoTypeHttpRequest: ...

        def deidentifyTemplates(self) -> DeidentifyTemplatesResource: ...
        def inspectTemplates(self) -> InspectTemplatesResource: ...
        def locations(self) -> LocationsResource: ...
        def storedInfoTypes(self) -> StoredInfoTypesResource: ...

    @typing.type_check_only
    class ProjectsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class ContentResource(googleapiclient.discovery.Resource):
            def deidentify(
                self,
                *,
                parent: str,
                body: GooglePrivacyDlpV2DeidentifyContentRequest = ...,
                **kwargs: typing.Any
            ) -> GooglePrivacyDlpV2DeidentifyContentResponseHttpRequest: ...
            def inspect(
                self,
                *,
                parent: str,
                body: GooglePrivacyDlpV2InspectContentRequest = ...,
                **kwargs: typing.Any
            ) -> GooglePrivacyDlpV2InspectContentResponseHttpRequest: ...
            def reidentify(
                self,
                *,
                parent: str,
                body: GooglePrivacyDlpV2ReidentifyContentRequest = ...,
                **kwargs: typing.Any
            ) -> GooglePrivacyDlpV2ReidentifyContentResponseHttpRequest: ...

        @typing.type_check_only
        class DeidentifyTemplatesResource(googleapiclient.discovery.Resource):
            def create(
                self,
                *,
                parent: str,
                body: GooglePrivacyDlpV2CreateDeidentifyTemplateRequest = ...,
                **kwargs: typing.Any
            ) -> GooglePrivacyDlpV2DeidentifyTemplateHttpRequest: ...
            def delete(
                self, *, name: str, **kwargs: typing.Any
            ) -> GoogleProtobufEmptyHttpRequest: ...
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> GooglePrivacyDlpV2DeidentifyTemplateHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                locationId: str = ...,
                orderBy: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> GooglePrivacyDlpV2ListDeidentifyTemplatesResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: GooglePrivacyDlpV2ListDeidentifyTemplatesResponseHttpRequest,
                previous_response: GooglePrivacyDlpV2ListDeidentifyTemplatesResponse,
            ) -> GooglePrivacyDlpV2ListDeidentifyTemplatesResponseHttpRequest | None: ...
            def patch(
                self,
                *,
                name: str,
                body: GooglePrivacyDlpV2UpdateDeidentifyTemplateRequest = ...,
                **kwargs: typing.Any
            ) -> GooglePrivacyDlpV2DeidentifyTemplateHttpRequest: ...

        @typing.type_check_only
        class DlpJobsResource(googleapiclient.discovery.Resource):
            def cancel(
                self,
                *,
                name: str,
                body: GooglePrivacyDlpV2CancelDlpJobRequest = ...,
                **kwargs: typing.Any
            ) -> GoogleProtobufEmptyHttpRequest: ...
            def create(
                self,
                *,
                parent: str,
                body: GooglePrivacyDlpV2CreateDlpJobRequest = ...,
                **kwargs: typing.Any
            ) -> GooglePrivacyDlpV2DlpJobHttpRequest: ...
            def delete(
                self, *, name: str, **kwargs: typing.Any
            ) -> GoogleProtobufEmptyHttpRequest: ...
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> GooglePrivacyDlpV2DlpJobHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                filter: str = ...,
                locationId: str = ...,
                orderBy: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                type: typing_extensions.Literal[
                    "DLP_JOB_TYPE_UNSPECIFIED", "INSPECT_JOB", "RISK_ANALYSIS_JOB"
                ] = ...,
                **kwargs: typing.Any
            ) -> GooglePrivacyDlpV2ListDlpJobsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: GooglePrivacyDlpV2ListDlpJobsResponseHttpRequest,
                previous_response: GooglePrivacyDlpV2ListDlpJobsResponse,
            ) -> GooglePrivacyDlpV2ListDlpJobsResponseHttpRequest | None: ...

        @typing.type_check_only
        class ImageResource(googleapiclient.discovery.Resource):
            def redact(
                self,
                *,
                parent: str,
                body: GooglePrivacyDlpV2RedactImageRequest = ...,
                **kwargs: typing.Any
            ) -> GooglePrivacyDlpV2RedactImageResponseHttpRequest: ...

        @typing.type_check_only
        class InspectTemplatesResource(googleapiclient.discovery.Resource):
            def create(
                self,
                *,
                parent: str,
                body: GooglePrivacyDlpV2CreateInspectTemplateRequest = ...,
                **kwargs: typing.Any
            ) -> GooglePrivacyDlpV2InspectTemplateHttpRequest: ...
            def delete(
                self, *, name: str, **kwargs: typing.Any
            ) -> GoogleProtobufEmptyHttpRequest: ...
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> GooglePrivacyDlpV2InspectTemplateHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                locationId: str = ...,
                orderBy: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> GooglePrivacyDlpV2ListInspectTemplatesResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: GooglePrivacyDlpV2ListInspectTemplatesResponseHttpRequest,
                previous_response: GooglePrivacyDlpV2ListInspectTemplatesResponse,
            ) -> GooglePrivacyDlpV2ListInspectTemplatesResponseHttpRequest | None: ...
            def patch(
                self,
                *,
                name: str,
                body: GooglePrivacyDlpV2UpdateInspectTemplateRequest = ...,
                **kwargs: typing.Any
            ) -> GooglePrivacyDlpV2InspectTemplateHttpRequest: ...

        @typing.type_check_only
        class JobTriggersResource(googleapiclient.discovery.Resource):
            def activate(
                self,
                *,
                name: str,
                body: GooglePrivacyDlpV2ActivateJobTriggerRequest = ...,
                **kwargs: typing.Any
            ) -> GooglePrivacyDlpV2DlpJobHttpRequest: ...
            def create(
                self,
                *,
                parent: str,
                body: GooglePrivacyDlpV2CreateJobTriggerRequest = ...,
                **kwargs: typing.Any
            ) -> GooglePrivacyDlpV2JobTriggerHttpRequest: ...
            def delete(
                self, *, name: str, **kwargs: typing.Any
            ) -> GoogleProtobufEmptyHttpRequest: ...
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> GooglePrivacyDlpV2JobTriggerHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                filter: str = ...,
                locationId: str = ...,
                orderBy: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                type: typing_extensions.Literal[
                    "DLP_JOB_TYPE_UNSPECIFIED", "INSPECT_JOB", "RISK_ANALYSIS_JOB"
                ] = ...,
                **kwargs: typing.Any
            ) -> GooglePrivacyDlpV2ListJobTriggersResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: GooglePrivacyDlpV2ListJobTriggersResponseHttpRequest,
                previous_response: GooglePrivacyDlpV2ListJobTriggersResponse,
            ) -> GooglePrivacyDlpV2ListJobTriggersResponseHttpRequest | None: ...
            def patch(
                self,
                *,
                name: str,
                body: GooglePrivacyDlpV2UpdateJobTriggerRequest = ...,
                **kwargs: typing.Any
            ) -> GooglePrivacyDlpV2JobTriggerHttpRequest: ...

        @typing.type_check_only
        class LocationsResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class ContentResource(googleapiclient.discovery.Resource):
                def deidentify(
                    self,
                    *,
                    parent: str,
                    body: GooglePrivacyDlpV2DeidentifyContentRequest = ...,
                    **kwargs: typing.Any
                ) -> GooglePrivacyDlpV2DeidentifyContentResponseHttpRequest: ...
                def inspect(
                    self,
                    *,
                    parent: str,
                    body: GooglePrivacyDlpV2InspectContentRequest = ...,
                    **kwargs: typing.Any
                ) -> GooglePrivacyDlpV2InspectContentResponseHttpRequest: ...
                def reidentify(
                    self,
                    *,
                    parent: str,
                    body: GooglePrivacyDlpV2ReidentifyContentRequest = ...,
                    **kwargs: typing.Any
                ) -> GooglePrivacyDlpV2ReidentifyContentResponseHttpRequest: ...

            @typing.type_check_only
            class DeidentifyTemplatesResource(googleapiclient.discovery.Resource):
                def create(
                    self,
                    *,
                    parent: str,
                    body: GooglePrivacyDlpV2CreateDeidentifyTemplateRequest = ...,
                    **kwargs: typing.Any
                ) -> GooglePrivacyDlpV2DeidentifyTemplateHttpRequest: ...
                def delete(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GoogleProtobufEmptyHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GooglePrivacyDlpV2DeidentifyTemplateHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    locationId: str = ...,
                    orderBy: str = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> GooglePrivacyDlpV2ListDeidentifyTemplatesResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: GooglePrivacyDlpV2ListDeidentifyTemplatesResponseHttpRequest,
                    previous_response: GooglePrivacyDlpV2ListDeidentifyTemplatesResponse,
                ) -> GooglePrivacyDlpV2ListDeidentifyTemplatesResponseHttpRequest | None: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: GooglePrivacyDlpV2UpdateDeidentifyTemplateRequest = ...,
                    **kwargs: typing.Any
                ) -> GooglePrivacyDlpV2DeidentifyTemplateHttpRequest: ...

            @typing.type_check_only
            class DlpJobsResource(googleapiclient.discovery.Resource):
                def cancel(
                    self,
                    *,
                    name: str,
                    body: GooglePrivacyDlpV2CancelDlpJobRequest = ...,
                    **kwargs: typing.Any
                ) -> GoogleProtobufEmptyHttpRequest: ...
                def create(
                    self,
                    *,
                    parent: str,
                    body: GooglePrivacyDlpV2CreateDlpJobRequest = ...,
                    **kwargs: typing.Any
                ) -> GooglePrivacyDlpV2DlpJobHttpRequest: ...
                def delete(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GoogleProtobufEmptyHttpRequest: ...
                def finish(
                    self,
                    *,
                    name: str,
                    body: GooglePrivacyDlpV2FinishDlpJobRequest = ...,
                    **kwargs: typing.Any
                ) -> GoogleProtobufEmptyHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GooglePrivacyDlpV2DlpJobHttpRequest: ...
                def hybridInspect(
                    self,
                    *,
                    name: str,
                    body: GooglePrivacyDlpV2HybridInspectDlpJobRequest = ...,
                    **kwargs: typing.Any
                ) -> GooglePrivacyDlpV2HybridInspectResponseHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    filter: str = ...,
                    locationId: str = ...,
                    orderBy: str = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    type: typing_extensions.Literal[
                        "DLP_JOB_TYPE_UNSPECIFIED", "INSPECT_JOB", "RISK_ANALYSIS_JOB"
                    ] = ...,
                    **kwargs: typing.Any
                ) -> GooglePrivacyDlpV2ListDlpJobsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: GooglePrivacyDlpV2ListDlpJobsResponseHttpRequest,
                    previous_response: GooglePrivacyDlpV2ListDlpJobsResponse,
                ) -> GooglePrivacyDlpV2ListDlpJobsResponseHttpRequest | None: ...

            @typing.type_check_only
            class ImageResource(googleapiclient.discovery.Resource):
                def redact(
                    self,
                    *,
                    parent: str,
                    body: GooglePrivacyDlpV2RedactImageRequest = ...,
                    **kwargs: typing.Any
                ) -> GooglePrivacyDlpV2RedactImageResponseHttpRequest: ...

            @typing.type_check_only
            class InspectTemplatesResource(googleapiclient.discovery.Resource):
                def create(
                    self,
                    *,
                    parent: str,
                    body: GooglePrivacyDlpV2CreateInspectTemplateRequest = ...,
                    **kwargs: typing.Any
                ) -> GooglePrivacyDlpV2InspectTemplateHttpRequest: ...
                def delete(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GoogleProtobufEmptyHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GooglePrivacyDlpV2InspectTemplateHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    locationId: str = ...,
                    orderBy: str = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> GooglePrivacyDlpV2ListInspectTemplatesResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: GooglePrivacyDlpV2ListInspectTemplatesResponseHttpRequest,
                    previous_response: GooglePrivacyDlpV2ListInspectTemplatesResponse,
                ) -> GooglePrivacyDlpV2ListInspectTemplatesResponseHttpRequest | None: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: GooglePrivacyDlpV2UpdateInspectTemplateRequest = ...,
                    **kwargs: typing.Any
                ) -> GooglePrivacyDlpV2InspectTemplateHttpRequest: ...

            @typing.type_check_only
            class JobTriggersResource(googleapiclient.discovery.Resource):
                def activate(
                    self,
                    *,
                    name: str,
                    body: GooglePrivacyDlpV2ActivateJobTriggerRequest = ...,
                    **kwargs: typing.Any
                ) -> GooglePrivacyDlpV2DlpJobHttpRequest: ...
                def create(
                    self,
                    *,
                    parent: str,
                    body: GooglePrivacyDlpV2CreateJobTriggerRequest = ...,
                    **kwargs: typing.Any
                ) -> GooglePrivacyDlpV2JobTriggerHttpRequest: ...
                def delete(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GoogleProtobufEmptyHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GooglePrivacyDlpV2JobTriggerHttpRequest: ...
                def hybridInspect(
                    self,
                    *,
                    name: str,
                    body: GooglePrivacyDlpV2HybridInspectJobTriggerRequest = ...,
                    **kwargs: typing.Any
                ) -> GooglePrivacyDlpV2HybridInspectResponseHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    filter: str = ...,
                    locationId: str = ...,
                    orderBy: str = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    type: typing_extensions.Literal[
                        "DLP_JOB_TYPE_UNSPECIFIED", "INSPECT_JOB", "RISK_ANALYSIS_JOB"
                    ] = ...,
                    **kwargs: typing.Any
                ) -> GooglePrivacyDlpV2ListJobTriggersResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: GooglePrivacyDlpV2ListJobTriggersResponseHttpRequest,
                    previous_response: GooglePrivacyDlpV2ListJobTriggersResponse,
                ) -> GooglePrivacyDlpV2ListJobTriggersResponseHttpRequest | None: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: GooglePrivacyDlpV2UpdateJobTriggerRequest = ...,
                    **kwargs: typing.Any
                ) -> GooglePrivacyDlpV2JobTriggerHttpRequest: ...

            @typing.type_check_only
            class StoredInfoTypesResource(googleapiclient.discovery.Resource):
                def create(
                    self,
                    *,
                    parent: str,
                    body: GooglePrivacyDlpV2CreateStoredInfoTypeRequest = ...,
                    **kwargs: typing.Any
                ) -> GooglePrivacyDlpV2StoredInfoTypeHttpRequest: ...
                def delete(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GoogleProtobufEmptyHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GooglePrivacyDlpV2StoredInfoTypeHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    locationId: str = ...,
                    orderBy: str = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> GooglePrivacyDlpV2ListStoredInfoTypesResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: GooglePrivacyDlpV2ListStoredInfoTypesResponseHttpRequest,
                    previous_response: GooglePrivacyDlpV2ListStoredInfoTypesResponse,
                ) -> GooglePrivacyDlpV2ListStoredInfoTypesResponseHttpRequest | None: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: GooglePrivacyDlpV2UpdateStoredInfoTypeRequest = ...,
                    **kwargs: typing.Any
                ) -> GooglePrivacyDlpV2StoredInfoTypeHttpRequest: ...

            def content(self) -> ContentResource: ...
            def deidentifyTemplates(self) -> DeidentifyTemplatesResource: ...
            def dlpJobs(self) -> DlpJobsResource: ...
            def image(self) -> ImageResource: ...
            def inspectTemplates(self) -> InspectTemplatesResource: ...
            def jobTriggers(self) -> JobTriggersResource: ...
            def storedInfoTypes(self) -> StoredInfoTypesResource: ...

        @typing.type_check_only
        class StoredInfoTypesResource(googleapiclient.discovery.Resource):
            def create(
                self,
                *,
                parent: str,
                body: GooglePrivacyDlpV2CreateStoredInfoTypeRequest = ...,
                **kwargs: typing.Any
            ) -> GooglePrivacyDlpV2StoredInfoTypeHttpRequest: ...
            def delete(
                self, *, name: str, **kwargs: typing.Any
            ) -> GoogleProtobufEmptyHttpRequest: ...
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> GooglePrivacyDlpV2StoredInfoTypeHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                locationId: str = ...,
                orderBy: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> GooglePrivacyDlpV2ListStoredInfoTypesResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: GooglePrivacyDlpV2ListStoredInfoTypesResponseHttpRequest,
                previous_response: GooglePrivacyDlpV2ListStoredInfoTypesResponse,
            ) -> GooglePrivacyDlpV2ListStoredInfoTypesResponseHttpRequest | None: ...
            def patch(
                self,
                *,
                name: str,
                body: GooglePrivacyDlpV2UpdateStoredInfoTypeRequest = ...,
                **kwargs: typing.Any
            ) -> GooglePrivacyDlpV2StoredInfoTypeHttpRequest: ...

        def content(self) -> ContentResource: ...
        def deidentifyTemplates(self) -> DeidentifyTemplatesResource: ...
        def dlpJobs(self) -> DlpJobsResource: ...
        def image(self) -> ImageResource: ...
        def inspectTemplates(self) -> InspectTemplatesResource: ...
        def jobTriggers(self) -> JobTriggersResource: ...
        def locations(self) -> LocationsResource: ...
        def storedInfoTypes(self) -> StoredInfoTypesResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def infoTypes(self) -> InfoTypesResource: ...
    def locations(self) -> LocationsResource: ...
    def organizations(self) -> OrganizationsResource: ...
    def projects(self) -> ProjectsResource: ...

@typing.type_check_only
class GooglePrivacyDlpV2DeidentifyContentResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GooglePrivacyDlpV2DeidentifyContentResponse: ...

@typing.type_check_only
class GooglePrivacyDlpV2DeidentifyTemplateHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GooglePrivacyDlpV2DeidentifyTemplate: ...

@typing.type_check_only
class GooglePrivacyDlpV2DlpJobHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GooglePrivacyDlpV2DlpJob: ...

@typing.type_check_only
class GooglePrivacyDlpV2HybridInspectResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GooglePrivacyDlpV2HybridInspectResponse: ...

@typing.type_check_only
class GooglePrivacyDlpV2InspectContentResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GooglePrivacyDlpV2InspectContentResponse: ...

@typing.type_check_only
class GooglePrivacyDlpV2InspectTemplateHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GooglePrivacyDlpV2InspectTemplate: ...

@typing.type_check_only
class GooglePrivacyDlpV2JobTriggerHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GooglePrivacyDlpV2JobTrigger: ...

@typing.type_check_only
class GooglePrivacyDlpV2ListDeidentifyTemplatesResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GooglePrivacyDlpV2ListDeidentifyTemplatesResponse: ...

@typing.type_check_only
class GooglePrivacyDlpV2ListDlpJobsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GooglePrivacyDlpV2ListDlpJobsResponse: ...

@typing.type_check_only
class GooglePrivacyDlpV2ListInfoTypesResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GooglePrivacyDlpV2ListInfoTypesResponse: ...

@typing.type_check_only
class GooglePrivacyDlpV2ListInspectTemplatesResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GooglePrivacyDlpV2ListInspectTemplatesResponse: ...

@typing.type_check_only
class GooglePrivacyDlpV2ListJobTriggersResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GooglePrivacyDlpV2ListJobTriggersResponse: ...

@typing.type_check_only
class GooglePrivacyDlpV2ListStoredInfoTypesResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GooglePrivacyDlpV2ListStoredInfoTypesResponse: ...

@typing.type_check_only
class GooglePrivacyDlpV2RedactImageResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GooglePrivacyDlpV2RedactImageResponse: ...

@typing.type_check_only
class GooglePrivacyDlpV2ReidentifyContentResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GooglePrivacyDlpV2ReidentifyContentResponse: ...

@typing.type_check_only
class GooglePrivacyDlpV2StoredInfoTypeHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GooglePrivacyDlpV2StoredInfoType: ...

@typing.type_check_only
class GoogleProtobufEmptyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleProtobufEmpty: ...



import typing

import typing_extensions

_list = list

@typing.type_check_only
class SiteSummaryResponse(typing_extensions.TypedDict, total=False):
    abusiveStatus: typing_extensions.Literal["UNKNOWN", "PASSING", "FAILING"]
    enforcementTime: str
    filterStatus: typing_extensions.Literal["UNKNOWN", "ON", "OFF", "PAUSED", "PENDING"]
    lastChangeTime: str
    reportUrl: str
    reviewedSite: str
    underReview: bool

@typing.type_check_only
class ViolatingSitesResponse(typing_extensions.TypedDict, total=False):
    violatingSites: _list[SiteSummaryResponse]
